@@ -6,15 +6,15 @@ class LogNormalModelInput(pydantic.BaseModel):
     num_qubits: pydantic.PositiveInt = pydantic.Field(
         description="Number of qubits to represent the probability."
     )
-    mu: pydantic.confloat(ge=0) = pydantic.Field(
+    mu: pydantic.NonNegativeFloat = pydantic.Field(
         description="Mean of the Normal distribution variable X s.t. ln(X) ~ log-normal."
     )
-    sigma: pydantic.confloat(gt=0) = pydantic.Field(
+    sigma: pydantic.PositiveFloat = pydantic.Field(
         description="Std of the Normal distribution variable X s.t. ln(X) ~ log-normal."
     )
 
     @property
-    def bounds(self):
+    def distribution_range(self):
         mean = np.exp(self.mu + self.sigma ** 2 / 2)
         variance = (np.exp(self.sigma ** 2) - 1) * np.exp(2 * self.mu + self.sigma ** 2)
         stddev = np.sqrt(variance)
