@@ -1,13 +1,13 @@
-from typing import Optional, Union, List, Literal
-
-from classiq_interface.hybrid.mht_input import (
-    EntanglementStructureType,
-    EntanglementBlocksType,
-    RotationBlocksType,
-)
+from typing import List, Optional, Union
 
 import pydantic
 
+from classiq_interface.hybrid.mht_input import (
+    EntanglementBlocksType,
+    EntanglementStructureType,
+    RotationBlocksType,
+)
+
 
 class CustomAnsatzArgs(pydantic.BaseModel):
     num_qubits: int
@@ -22,18 +22,18 @@ class HypercubeArgs(CustomAnsatzArgs):
 
 
 class EntanglingLayersArgs(CustomAnsatzArgs):
-    layer_count: int = (2,)
+    layer_count: int = 2
 
 
 class RandomArgs(CustomAnsatzArgs):
-    gate_count: int = (100,)
-    gate_probabilities: dict = ({"cx": 0.5, "u": 0.5},)
-    random_seed: int = None
+    gate_count: int = 100
+    gate_probabilities: dict = {"cx": 0.5, "u": 0.5}
+    random_seed: Union[int, None] = None
 
 
 class RandomTwoQubitGatesArgs(CustomAnsatzArgs):
-    random_two_qubit_gate_count_factor: float = (1.0,)
-    random_seed: int = None
+    random_two_qubit_gate_count_factor: float = 1.0
+    random_seed: Union[int, None] = None
 
 
 class TwoLocalArgs(CustomAnsatzArgs):
