@@ -1,19 +1,13 @@
-from enum import Enum
-from typing import Type, Optional
+from typing import List, Optional
 
 import pydantic
 
 from classiq_interface.generator.function_params import FunctionParams
 
-
-class McxInputs(Enum):
-    CTRL_IN = "CTRL_IN"
-    TARGET_QUBIT_IN = "TARGET_QUBIT"
-
-
-class McxOutputs(Enum):
-    CTRL_OUT = "CTRL_OUT"
-    TARGET_QUBIT_OUT = "TARGET_QUBIT_OUT"
+CTRL_IN = "CTRL_IN"
+TARGET_QUBIT_IN = "TARGET_QUBIT"
+CTRL_OUT = "CTRL_OUT"
+TARGET_QUBIT_OUT = "TARGET_QUBIT_OUT"
 
 
 class Mcx(FunctionParams):
@@ -40,5 +34,7 @@ class Mcx(FunctionParams):
             )
         return ctrl_state
 
-    _input_names: Type[Enum] = pydantic.PrivateAttr(default=McxInputs)
-    _output_names: Type[Enum] = pydantic.PrivateAttr(default=McxOutputs)
+    _input_names: List[str] = pydantic.PrivateAttr(default=[CTRL_IN, TARGET_QUBIT_IN])
+    _output_names: List[str] = pydantic.PrivateAttr(
+        default=[CTRL_OUT, TARGET_QUBIT_OUT]
+    )
