@@ -7,14 +7,14 @@ from classiq_interface.hybrid.mvc_input import MVCInput
 from classiq_interface.hybrid.problem_input import OptimizationProblemName, ProblemInput
 from classiq_interface.hybrid.tsp_input import TSPInput
 
-PROBLEM_INPUT_MAPPING = {
+PROBLEM_INPUT_MAPPING: dict = {
     OptimizationProblemName.TSP: TSPInput,
     OptimizationProblemName.MVC: MVCInput,
     OptimizationProblemName.MHT: MHTInput,
     OptimizationProblemName.MhtQaoa: MhtQaoaInput,
 }
 
-ENCODING_TYPE_DEFAULT = {
+ENCODING_TYPE_DEFAULT: dict = {
     TSPInput: EncodingType.NODES,
     MVCInput: EncodingType.DICKE,
     MHTInput: EncodingType.SERIAL,
