@@ -1,11 +1,9 @@
-from typing import Type, Tuple
+from typing import Tuple, Type
 
 import pydantic
 
-from classiq_interface.generator.problem_properties import (
-    ProblemProperties,
-)
 from classiq_interface.generator.function_params import FunctionParams
+from classiq_interface.generator.problem_properties import ProblemProperties
 from classiq_interface.hybrid.mht_qaoa_input import MhtQaoaInput
 from classiq_interface.hybrid.problem_input import ProblemInput
 
