@@ -1,16 +1,17 @@
 import enum
-from typing import Optional, List, Union
+from typing import List, Optional, Union
 
 import pydantic
-import qiskit
 
-from classiq_interface.generator.generation_metadata import GenerationMetadata
-from classiq_interface.generator.noise_properties import NoiseProperties
 from classiq_interface.backend.backend_preferences import (
     AwsBackendPreferences,
-    IBMBackendPreferences,
     AzureBackendPreferences,
+    IBMBackendPreferences,
 )
+from classiq_interface.combinatorial_optimization.solver_types import QSolver
+from classiq_interface.generator.generation_metadata import GenerationMetadata
+from classiq_interface.generator.noise_properties import NoiseProperties
+from classiq_interface.helpers.custom_pydantic_types import pydanticAlphaParamCVAR
 
 
 class VerbosityLevel(str, enum.Enum):
@@ -45,7 +46,7 @@ class VQEPreferences(pydantic.BaseModel):
         "The server must accept POST requests with field 'trk_list' and return"
         "a response with field 'score'.",
     )
-    alpha_cvar: pydantic.confloat(gt=0, le=1) = pydantic.Field(
+    alpha_cvar: pydanticAlphaParamCVAR = pydantic.Field(
         default=None, description="Parameter for the CVAR summarizing method"
     )
     max_iteration: pydantic.PositiveInt = pydantic.Field(
@@ -66,24 +67,27 @@ class VQEPreferences(pydantic.BaseModel):
         "solutions. Set to null to "
         "fetch all solutions.",
     )
-    use_gpu: bool = pydantic.Field(
-        default=True, description="Try simulating on GPU if available."
-    )
     invalid_space_cost_threshold: Optional[pydantic.PositiveFloat] = pydantic.Field(
         default=None,
         description="Solutions with cost greater or equal to that value, are considered invalid.",
     )
-    is_penalty: bool = pydantic.Field(
-        default=True,
+    qsolver: QSolver = pydantic.Field(
+        default=QSolver.QAOAPenalty,
         description="Indicates whether to use QAOA with penalty terms or constrained QAOA.",
     )
+    penalty_energy: float = pydantic.Field(
+        default=2,
+        description="Penalty energy for invalid solutions. The value affects "
+        "the converges rate. Small positive values are preferred",
+    )
 
     @pydantic.validator("alpha_cvar", pre=True, always=True)
     def check_alpha_cvar(cls, alpha_cvar, values):
-        if alpha_cvar is not None and values["cost_type"] != CostType.CVAR:
+        cost_type = values.get("cost_type")
+        if alpha_cvar is not None and cost_type != CostType.CVAR:
             raise ValueError("Use CVAR params only when relevant.")
 
-        if alpha_cvar is None and values["cost_type"] == CostType.CVAR:
+        if alpha_cvar is None and cost_type == CostType.CVAR:
             alpha_cvar = 0.04
 
         return alpha_cvar
@@ -130,15 +134,16 @@ class VQEProblem(pydantic.BaseModel):
 
     @pydantic.validator("warm_start")
     def check_num_of_params_assign(cls, warm_start, values):
-        if warm_start is None:
-            return warm_start
-
-        ansatz = values.get("ansatz")
-        circuit_param = qiskit.QuantumCircuit.from_qasm_str(ansatz).parameters
-
-        if len(warm_start) != len(circuit_param):
-            raise ValueError(
-                "Number of parameters assigned does not match number of parameters in circuit"
-            )
+        # TODO: deprecate completely
+        # if warm_start is None:
+        #     return warm_start
+        #
+        # ansatz = values.get("ansatz")
+        # circuit_param = qiskit.QuantumCircuit.from_qasm_str(ansatz).parameters
+        #
+        # if len(warm_start) != len(circuit_param):
+        #     raise ValueError(
+        #         "Number of parameters assigned does not match number of parameters in circuit"
+        #     )
 
         return warm_start
